
'''
This file is automatically generated; Do not edit it. :)
'''
VERSION_INFO = {
    'final': True,
    'version': '1.20.15',
    'branch_nick': 'release-1.20-LTS',
    'revision_id': '63c3b468709e502f5f74943d37083e22f0445296',
    'revno': 8668
}
